@@ -116,8 +116,7 @@ public class PhysicalFsWriter implements PhysicalWriter {
     CompressionCodec codec = OrcCodecPool.getCodec(opts.getCompress());
     if (codec != null){
       CompressionCodec.Options tempOptions = codec.getDefaultOptions();
-      if (codec instanceof ZstdCodec &&
-              codec.getDefaultOptions() instanceof ZstdCodec.ZstdOptions options) {
+      if (codec instanceof ZstdCodec && tempOptions instanceof ZstdCodec.ZstdOptions options) {
         OrcFile.ZstdCompressOptions zstdCompressOptions = opts.getZstdCompressOptions();
         if (zstdCompressOptions != null) {
           options.setLevel(zstdCompressOptions.getCompressionZstdLevel());
