@@ -30,50 +30,50 @@ TEST(TestFileMetadata, testRaw) {
   const std::string expected = "Raw file tail: " + file +
                                "\n"
                                "postscript {\n"
-                               "  footerLength: 288\n"
+                               "  footer_length: 288\n"
                                "  compression: NONE\n"
                                "  version: 0\n"
                                "  version: 12\n"
-                               "  metadataLength: 526\n"
+                               "  metadata_length: 526\n"
                                "  magic: \"ORC\"\n"
                                "}\n"
                                "footer {\n"
-                               "  headerLength: 3\n"
-                               "  contentLength: 245568\n"
+                               "  header_length: 3\n"
+                               "  content_length: 245568\n"
                                "  stripes {\n"
                                "    offset: 3\n"
-                               "    indexLength: 137\n"
-                               "    dataLength: 45282\n"
-                               "    footerLength: 149\n"
-                               "    numberOfRows: 5000\n"
+                               "    index_length: 137\n"
+                               "    data_length: 45282\n"
+                               "    footer_length: 149\n"
+                               "    number_of_rows: 5000\n"
                                "  }\n"
                                "  stripes {\n"
                                "    offset: 45571\n"
-                               "    indexLength: 137\n"
-                               "    dataLength: 45282\n"
-                               "    footerLength: 149\n"
-                               "    numberOfRows: 5000\n"
+                               "    index_length: 137\n"
+                               "    data_length: 45282\n"
+                               "    footer_length: 149\n"
+                               "    number_of_rows: 5000\n"
                                "  }\n"
                                "  stripes {\n"
                                "    offset: 91139\n"
-                               "    indexLength: 137\n"
-                               "    dataLength: 45282\n"
-                               "    footerLength: 149\n"
-                               "    numberOfRows: 5000\n"
+                               "    index_length: 137\n"
+                               "    data_length: 45282\n"
+                               "    footer_length: 149\n"
+                               "    number_of_rows: 5000\n"
                                "  }\n"
                                "  stripes {\n"
                                "    offset: 136707\n"
-                               "    indexLength: 138\n"
-                               "    dataLength: 45283\n"
-                               "    footerLength: 149\n"
-                               "    numberOfRows: 5000\n"
+                               "    index_length: 138\n"
+                               "    data_length: 45283\n"
+                               "    footer_length: 149\n"
+                               "    number_of_rows: 5000\n"
                                "  }\n"
                                "  stripes {\n"
                                "    offset: 200000\n"
-                               "    indexLength: 137\n"
-                               "    dataLength: 45282\n"
-                               "    footerLength: 149\n"
-                               "    numberOfRows: 5000\n"
+                               "    index_length: 137\n"
+                               "    data_length: 45282\n"
+                               "    footer_length: 149\n"
+                               "    number_of_rows: 5000\n"
                                "  }\n"
                                "  types {\n"
                                "    kind: STRUCT\n"
@@ -82,11 +82,11 @@ TEST(TestFileMetadata, testRaw) {
                                "    subtypes: 3\n"
                                "    subtypes: 4\n"
                                "    subtypes: 5\n"
-                               "    fieldNames: \"userid\"\n"
-                               "    fieldNames: \"string1\"\n"
-                               "    fieldNames: \"subtype\"\n"
-                               "    fieldNames: \"decimal1\"\n"
-                               "    fieldNames: \"ts\"\n"
+                               "    field_names: \"userid\"\n"
+                               "    field_names: \"string1\"\n"
+                               "    field_names: \"subtype\"\n"
+                               "    field_names: \"decimal1\"\n"
+                               "    field_names: \"ts\"\n"
                                "  }\n"
                                "  types {\n"
                                "    kind: LONG\n"
@@ -103,49 +103,49 @@ TEST(TestFileMetadata, testRaw) {
                                "  types {\n"
                                "    kind: TIMESTAMP\n"
                                "  }\n"
-                               "  numberOfRows: 25000\n"
+                               "  number_of_rows: 25000\n"
                                "  statistics {\n"
-                               "    numberOfValues: 25000\n"
+                               "    number_of_values: 25000\n"
                                "  }\n"
                                "  statistics {\n"
-                               "    numberOfValues: 25000\n"
-                               "    intStatistics {\n"
+                               "    number_of_values: 25000\n"
+                               "    int_statistics {\n"
                                "      minimum: 2\n"
                                "      maximum: 100\n"
                                "      sum: 2499619\n"
                                "    }\n"
                                "  }\n"
                                "  statistics {\n"
-                               "    numberOfValues: 25000\n"
-                               "    stringStatistics {\n"
+                               "    number_of_values: 25000\n"
+                               "    string_statistics {\n"
                                "      minimum: \"bar\"\n"
                                "      maximum: \"zebra\"\n"
                                "      sum: 124990\n"
                                "    }\n"
                                "  }\n"
                                "  statistics {\n"
-                               "    numberOfValues: 25000\n"
-                               "    doubleStatistics {\n"
+                               "    number_of_values: 25000\n"
+                               "    double_statistics {\n"
                                "      minimum: 0.8\n"
                                "      maximum: 80\n"
                                "      sum: 200051.40000000002\n"
                                "    }\n"
                                "  }\n"
                                "  statistics {\n"
-                               "    numberOfValues: 25000\n"
-                               "    decimalStatistics {\n"
+                               "    number_of_values: 25000\n"
+                               "    decimal_statistics {\n"
                                "      minimum: \"0\"\n"
                                "      maximum: \"5.5\"\n"
                                "      sum: \"16.6\"\n"
                                "    }\n"
                                "  }\n"
                                "  statistics {\n"
-                               "    numberOfValues: 25000\n"
+                               "    number_of_values: 25000\n"
                                "  }\n"
-                               "  rowIndexStride: 10000\n"
+                               "  row_index_stride: 10000\n"
                                "}\n"
-                               "fileLength: 246402\n"
-                               "postscriptLength: 19\n";
+                               "file_length: 246402\n"
+                               "postscript_length: 19\n";
   std::string output;
   std::string error;
 
