@@ -30,12 +30,12 @@ TEST(TestFileStatistics, testNormal) {
   const std::string expected = "File " + file +
                                " has 3 columns\n"
                                "*** Column 0 ***\n"
-                               "Column has 6000 values and has null value: no\n"
+                               "Column has 6000 values and has null value: yes\n"
                                "\n"
                                "*** Column 1 ***\n"
                                "Data type: Integer\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1\n"
                                "Maximum: 6000\n"
                                "Sum: 18003000\n"
@@ -43,7 +43,7 @@ TEST(TestFileStatistics, testNormal) {
                                "*** Column 2 ***\n"
                                "Data type: String\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1000\n"
                                "Maximum: 9a\n"
                                "Total length: 23892\n"
@@ -54,12 +54,12 @@ TEST(TestFileStatistics, testNormal) {
                                "*** Stripe 0 ***\n"
                                "\n"
                                "--- Column 0 ---\n"
-                               "Column has 6000 values and has null value: no\n"
+                               "Column has 6000 values and has null value: yes\n"
                                "\n"
                                "--- Column 1 ---\n"
                                "Data type: Integer\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1\n"
                                "Maximum: 6000\n"
                                "Sum: 18003000\n"
@@ -67,7 +67,7 @@ TEST(TestFileStatistics, testNormal) {
                                "--- Column 2 ---\n"
                                "Data type: String\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1000\n"
                                "Maximum: 9a\n"
                                "Total length: 23892\n\n";
@@ -86,12 +86,12 @@ TEST(TestFileStatistics, testOptions) {
   const std::string expected = "File " + file +
                                " has 3 columns\n"
                                "*** Column 0 ***\n"
-                               "Column has 6000 values and has null value: no\n"
+                               "Column has 6000 values and has null value: yes\n"
                                "\n"
                                "*** Column 1 ***\n"
                                "Data type: Integer\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1\n"
                                "Maximum: 6000\n"
                                "Sum: 18003000\n"
@@ -99,7 +99,7 @@ TEST(TestFileStatistics, testOptions) {
                                "*** Column 2 ***\n"
                                "Data type: String\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1000\n"
                                "Maximum: 9a\n"
                                "Total length: 23892\n"
@@ -110,21 +110,21 @@ TEST(TestFileStatistics, testOptions) {
                                "*** Stripe 0 ***\n"
                                "\n"
                                "--- Column 0 ---\n"
-                               "Column has 6000 values and has null value: no\n"
+                               "Column has 6000 values and has null value: yes\n"
                                "\n"
                                "--- RowIndex 0 ---\n"
-                               "Column has 2000 values and has null value: no\n"
+                               "Column has 2000 values and has null value: yes\n"
                                "\n"
                                "--- RowIndex 1 ---\n"
-                               "Column has 2000 values and has null value: no\n"
+                               "Column has 2000 values and has null value: yes\n"
                                "\n"
                                "--- RowIndex 2 ---\n"
-                               "Column has 2000 values and has null value: no\n"
+                               "Column has 2000 values and has null value: yes\n"
                                "\n"
                                "--- Column 1 ---\n"
                                "Data type: Integer\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1\n"
                                "Maximum: 6000\n"
                                "Sum: 18003000\n"
@@ -132,7 +132,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- RowIndex 0 ---\n"
                                "Data type: Integer\n"
                                "Values: 2000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1\n"
                                "Maximum: 2000\n"
                                "Sum: 2001000\n"
@@ -140,7 +140,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- RowIndex 1 ---\n"
                                "Data type: Integer\n"
                                "Values: 2000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 2001\n"
                                "Maximum: 4000\n"
                                "Sum: 6001000\n"
@@ -148,7 +148,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- RowIndex 2 ---\n"
                                "Data type: Integer\n"
                                "Values: 2000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 4001\n"
                                "Maximum: 6000\n"
                                "Sum: 10001000\n"
@@ -156,7 +156,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- Column 2 ---\n"
                                "Data type: String\n"
                                "Values: 6000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1000\n"
                                "Maximum: 9a\n"
                                "Total length: 23892\n"
@@ -164,7 +164,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- RowIndex 0 ---\n"
                                "Data type: String\n"
                                "Values: 2000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 1000\n"
                                "Maximum: 9a\n"
                                "Total length: 7892\n"
@@ -172,7 +172,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- RowIndex 1 ---\n"
                                "Data type: String\n"
                                "Values: 2000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 2001\n"
                                "Maximum: 4000\n"
                                "Total length: 8000\n"
@@ -180,7 +180,7 @@ TEST(TestFileStatistics, testOptions) {
                                "--- RowIndex 2 ---\n"
                                "Data type: String\n"
                                "Values: 2000\n"
-                               "Has null: no\n"
+                               "Has null: yes\n"
                                "Minimum: 4001\n"
                                "Maximum: 6000\n"
                                "Total length: 8000\n\n";
